/*
 * Copyright 2003 - 2010 The eFaps Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Revision:        $Rev: 3601 $
 * Last Changed:    $Date: 2010-01-05 15:53:16 -0500 (Tue, 05 Jan 2010) $
 * Last Changed By: $Author: tim.moxter $
 */

package org.efaps.wikiutil.wom.element.text;

import org.apache.commons.lang.builder.ToStringBuilder;

/**
 * An internal link with description within a text.
 *
 * @author The eFaps Team
 * @version $Id: InternalLinkWithDescription.java 3601 2010-01-05 20:53:16Z tim.moxter $
 */
public class InternalLinkWithDescription
    extends AbstractInternalLink
{
    /**
     * Description of the internal link.
     */
    private final String description;

    /**
     * Initializes this internal link with {@link #description}.
     *
     * @param _link         internal link
     * @param _description  description of the internal link
     */
    public InternalLinkWithDescription(final CharSequence _link,
                                       final CharSequence _description)
    {
        super(_link);
        this.description = _description.toString();
    }

    /**
     * Returns the description of this internal link.
     *
     * @return description of the internal link
     * @see #description
     */
    public String getDescription()
    {
        return this.description;
    }

    /**
     * Returns the string representation of this external link including the
     * {@link #description}.
     *
     * @return string representation
     */
    @Override()
    public String toString()
    {
        return new ToStringBuilder(this)
            .appendSuper(super.toString())
            .append("description", this.description)
            .toString();
    }
}
